#!/usr/bin/env python

#from setuptools import setup, Extension
from distutils.core import setup, Extension

import numpy
numpy_include = numpy.get_include()

comp = Extension('pyfits.compression', [
	'src/compress.c',
	'src/fits_hcompress.c',
	'src/fits_hdecompress.c',
	'src/fitsio.c',
	'src/pliocomp.c',
	'src/compressionmodule.c',
	'src/quantize.c',
	'src/ricecomp.c',
	],
        libraries=['z'],
	include_dirs=[numpy_include])

setup(name='pyfits',
	version='3.1.1',
	author= 'J. C. Hsu, Paul Barrett, Christopher Hanley, James Taylor, Michael Droettboom, Erik Bray',
	author_email='help@stsci.edu',
	description='Reads FITS images and tables into numpy or numarray objects and manipulates FITS headers',
	url='http://www.stsci.edu/resources/software_hardware/pyfits',
	classifiers=[ 
	"Intended Audience :: Science/Research",
	"License :: OSI Approved :: BSD License",
	"Operating System :: OS Independent",
	"Programming Language :: Python",
	"Programming Language :: Python :: 3",
	"Topic :: Scientific/Engineering :: Astronomy",
	"Topic :: Software Development :: Libraries :: Python Modules",
	],
	package_dir={'': 'lib'},
	packages=['pyfits', 'pyfits.hdu', 'pyfits.scripts', 'pyfits.tests'],
        ext_modules=[comp],
	package_data={"pyfits.tests": ["data/*.fits"]},
	scripts=['scripts/fitscheck', 'scripts/fitsdiff'],
	)

