%define __python /usr/bin/python2.7
%global pybindir /usr/lib/python2.7/bin

%if 0%{?fedora} > 12
%global with_python3 1
%else
%{!?python_sitearch: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print (get_python_lib(1))")}
%endif

Name: pyfits27
Version: 3.1.1
Release: 1%{?dist}.1
Summary: Python interface to FITS

Group: Development/Languages
License: BSD

URL: http://www.stsci.edu/resources/software_hardware/pyfits
Source0: http://pypi.python.org/packages/source/p/pyfits/pyfits-%{version}.tar.gz
Source1: pyfits-compat-setup.py
Patch0: pyfits-unbundle-z.patch

BuildRequires: python27-devel python27-setuptools numpy27 zlib-devel
Requires: numpy27


# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python_sitearch}/.*\.so$ 
%filter_setup
}

%description
PyFITS provides an interface to FITS formatted files under the Python 
scripting language. It is useful both for interactive data analysis and for 
writing analysis scripts in Python using FITS files as either input or output. 

%if 0%{?with_python3}
%package -n python3-pyfits
Summary: Python interface to FITS
BuildRequires: python3-devel python3-numpy python3-setuptools python3-tools
BuildRequires: zlib-devel
Requires: python3-numpy

# we don't want to provide private python extension libs
%{?filter_setup:
%filter_provides_in %{python3_sitearch}/.*\.so$ 
%filter_setup
}

%description -n python3-pyfits
PyFITS provides an interface to FITS formatted files under the Python 
scripting language. It is useful both for interactive data analysis and for 
writing analysis scripts in Python using FITS files as either input or output. 
%endif # with_python3

%prep
%setup -q -n pyfits-%{version}
%patch0 -p1
sed -i -e "1d" lib/pyfits/core.py
rm -f setup.py setup.cfg
# remove bundled zlib
pushd src
rm crc32.h deflate.h inffast.c inffast.h inffixed.h inflate.h inftrees.c \
inftrees.h trees.c trees.h zlib.c zlib.h zutil.h
popd
cp %SOURCE1 setup.py

%if 0%{?with_python3}
rm -rf %{py3dir}
cp -a . %{py3dir}
find %{py3dir} -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python3}|'
python3-2to3 --no-diffs --write --nobackup %{py3dir}
sed s/fitscheck/fitscheck-3/ -i %{py3dir}/setup.py
sed s/fitsdiff/fitsdiff-3/ -i %{py3dir}/setup.py
mv %{py3dir}/scripts/fitscheck %{py3dir}/scripts/fitscheck-3
mv %{py3dir}/scripts/fitsdiff %{py3dir}/scripts/fitsdiff-3
%endif # with_python3

find -name '*.py' | xargs sed -i '1s|^#!python|#!%{__python}|'

%build
CFLAGS="%{optflags}" %{__python} setup.py build

%if 0%{?with_python3}
pushd %{py3dir}
CFLAGS="%{optflags}" %{__python3} setup.py build
popd
%endif # with_python3

%install
rm -rf %{buildroot}
%if 0%{?with_python3}
pushd %{py3dir}
%{__python3} setup.py install --skip-build --root  %{buildroot}
chmod 755 %{buildroot}%{python3_sitearch}/pyfits/compression*.so
popd
%endif # with_python3

%{__python} setup.py install -O1 --skip-build --root  %{buildroot}
chmod 755 %{buildroot}%{python_sitearch}/pyfits/compression.so

mkdir -p %{buildroot}%{pybindir}
mv %{buildroot}%{_bindir}/fitscheck %{buildroot}%{_bindir}/fitscheck27
ln -s %{_bindir}/fitscheck27 %{buildroot}%{pybindir}/fitscheck
mv %{buildroot}%{_bindir}/fitsdiff %{buildroot}%{_bindir}/fitsdiff27
ln -s %{_bindir}/fitsdiff27 %{buildroot}%{pybindir}/fitsdiff

%files
%doc FAQ.txt README.txt LICENSE.txt CHANGES.txt
%{_bindir}/fitscheck*
%{_bindir}/fitsdiff*
%{pybindir}/fits*
%{python_sitearch}/*

%if 0%{?with_python3}
%files -n python3-pyfits
%doc FAQ.txt README.txt LICENSE.txt CHANGES.txt
# Provides the same functionality than the 2.x version
%exclude %{_bindir}/fitscheck-3
%exclude %{_bindir}/fitsdiff-3
%{python3_sitearch}/*
%endif # with_python3

%changelog
* Fri Jan 02 2013 Sergio Pascual <sergiopr@fedoraproject.org> - 3.1.1-1
- New upstream 3.1.1 (bugfixes)
- Added FAQ.txt and README.txt to doc

* Wed Aug 29 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.1-1
- New upstream 3.1
- New program fitscheck

* Sun Aug 05 2012 David Malcolm <dmalcolm@redhat.com> - 3.0.8-3
- rebuild for https://fedoraproject.org/wiki/Features/Python_3.3

* Sat Jul 21 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.8-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Thu Jun 21 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.8-1
- New upstream source
- A better patch to unbundle zlib from Kacper Kowalik (Gentoo)

* Wed Apr 25 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.7-3
- Added a filter to provides in python3-pyfits

* Wed Apr 25 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.7-2
- Unbundle zlib

* Tue Apr 24 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.7-1
- New upstream version

* Tue Apr 24 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.5-2
- Fixed bz #815376
- Moved python3 requires to package description

* Tue Jan 31 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.5-1
- New upstream version, mainly bugfixes

* Fri Jan 20 2012 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.1-3
- Added compatibility setup.py to avoid using d2to1 package
- Added a dependency on 2to3

* Sat Jan 14 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.0.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Sep 21 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 3.0.1-1
- New upstream version (with Python 3 support)
- Python 3 support enabled

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Jan 19 2011 Sergio Pascual <sergiopr@fedoraproject.org> - 2.4.0-1
- New upstream source
- Added filter macro to avoid private-shared-object-provides rpmlint warning

* Wed Jul 21 2010 David Malcolm <dmalcolm@redhat.com> - 2.3.1-2
- Rebuilt for https://fedoraproject.org/wiki/Features/Python_2.7/MassRebuild

* Wed Jun 23 2010 Sergio Pascual <sergiopr@fedoraproject.org> - 2.3.1-1
- New upstream source, Compressed Image code under BSD license

* Fri May 21 2010 Sergio Pascual <sergiopr@fedoraproject.org> - 2.3-1
- New upstream source

* Tue Jan 20 2010 Sergio Pascual <sergiopr@fedoraproject.org> - 2.2.2-3
- Added missing quotes in CFLAGS

* Tue Jan 20 2010 Sergio Pascual <sergiopr@fedoraproject.org> - 2.2.2-2
- Added CFLAGS to the build line

* Tue Nov 17 2009 Sergio Pascual <sergiopr@fedoraproject.org> - 2.2.2-1
- New upstream source

* Fri Sep 25 2009 Sergio Pascual <sergiopr@fedoraproject.org> - 2.2-1
- New upstream source

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.1.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Fri May 22 2009 Sergio Pascual <sergiopr@fedoraproject.org> - 2.1.1-2
- Fixed strange permision of the .so file

* Tue May 19 2009 Sergio Pascual <sergiopr@fedoraproject.org> - 2.1.1-1
- New upstream source with support for "tile image compression".

* Sat Nov 29 2008 Ignacio Vazquez-Abrams <ivazqueznet+rpm@gmail.com> - 1.3-4
- Rebuild for Python 2.6

* Tue Apr 08 2008 Sergio Pascual <sergiopr@fedoraproject.org> - 1.3-3
- Adding dist tag

* Sun Apr 06 2008 Sergio Pascual <sergiopr@fedoraproject.org> - 1.3-2
- Fixing setup not quiet
- Shebang removed from non-script python files

* Wed Mar 26 2008 Sergio Pascual <sergio.pasra@gmail.com> - 1.3-1
- Initial specfile

